Util
Date: 2015-08-04

jep

## Class Util

- java.lang.Object
- - jep.Util

-     public final class Util
      extends java.lang.Object

  Utility functions

- - ### Field Summary

    Fields
    Modifier and Type | Field and Description
    --- | ---
    `static int` | `JARRAY_ID`
    `static int` | `JBOOLEAN_ID`
    `static int` | `JBYTE_ID`
    `static int` | `JCHAR_ID`
    `static int` | `JCLASS_ID`
    `static int` | `JDOUBLE_ID`
    `static int` | `JFLOAT_ID`
    `static int` | `JINT_ID`
    `static int` | `JLONG_ID`
    `static int` | `JOBJECT_ID`
    `static int` | `JSHORT_ID`
    `static int` | `JSTRING_ID`
    `static int` | `JVOID_ID`

  - ### Method Summary

    Methods
    Modifier and Type | Method and Description
    --- | ---
    `static int` | `getTypeId(java.lang.Class<?> clazz)` Internal use only Same as `getTypeId(Object)` but for Class.
    `static int` | `getTypeId(java.lang.Object obj)` Internal use only Does the same thing as util.c::get_jtype, but it's easier more stable to do this in java when able.

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### JBOOLEAN_ID

          public static final int JBOOLEAN_ID

      See Also:
        Constant Field Values

    - #### JINT_ID

          public static final int JINT_ID

      See Also:
        Constant Field Values

    - #### JLONG_ID

          public static final int JLONG_ID

      See Also:
        Constant Field Values

    - #### JOBJECT_ID

          public static final int JOBJECT_ID

      See Also:
        Constant Field Values

    - #### JSTRING_ID

          public static final int JSTRING_ID

      See Also:
        Constant Field Values

    - #### JVOID_ID

          public static final int JVOID_ID

      See Also:
        Constant Field Values

    - #### JDOUBLE_ID

          public static final int JDOUBLE_ID

      See Also:
        Constant Field Values

    - #### JSHORT_ID

          public static final int JSHORT_ID

      See Also:
        Constant Field Values

    - #### JFLOAT_ID

          public static final int JFLOAT_ID

      See Also:
        Constant Field Values

    - #### JARRAY_ID

          public static final int JARRAY_ID

      See Also:
        Constant Field Values

    - #### JCHAR_ID

          public static final int JCHAR_ID

      See Also:
        Constant Field Values

    - #### JBYTE_ID

          public static final int JBYTE_ID

      See Also:
        Constant Field Values

    - #### JCLASS_ID

          public static final int JCLASS_ID

      See Also:
        Constant Field Values

  - ### Method Detail

    - #### getTypeId

          public static final int getTypeId(java.lang.Object obj)

           Internal use only

           Does the same thing as util.c::get_jtype, but it's easier more
           stable to do this in java when able.

      Parameters:
        `obj` - an `Object` value
      Returns:
        an `int` one of the type _ID constants

    - #### getTypeId

          public static final int getTypeId(java.lang.Class<?> clazz)

           Internal use only

           Same as getTypeId(Object) but for Class. This is
           useful for determining the _ID for things like
           method.getReturnType.

      Parameters:
        `clazz` - an `Object` value
      Returns:
        an `int` one of the type _ID constants